%define libteam_major     5
%define libteam_name      %mklibname team %{libteam_major}

%define libteamdctl_major 0
%define libteamdctl_name  %mklibname teamdctl %{libteamdctl_major}

%define develname         %mklibname team -d

Name:		libteam
Version:	1.32
Release:	%mkrel 3
Summary:	Utilities for controlling 802.1AX team network device
License:	LGPLv2+
Group:		System/Base
Url:		https://libteam.org/
Source0:	https://libteam.org/files/%{name}-%{version}.tar.gz
# Upstream patches
Patch1:		0001-teamd-Pass-correct-parameter-type-to-accept-API.patch
Patch2:		0002-teamd-lw-arp_ping-bitmask-VID-in-VLAN-BPF-filter.patch
# Others
Patch100:	python3.8.patch
# Fix for swig >= 4.1, deprecated syntax
Patch101:	fix-swig-4.1.patch
Patch102:	0001-Use-SWIG_AppendOutput.patch

BuildRequires:	doxygen
BuildRequires:	pyproject-rpm-macros
BuildRequires:	swig
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(libdaemon)
BuildRequires:	pkgconfig(libnl-3.0) >= 3.2.0
BuildRequires:	pkgconfig(libnl-cli-3.0) >= 3.2.0
BuildRequires:	pkgconfig(libnl-genl-3.0) >= 3.2.0
BuildRequires:	pkgconfig(libnl-route-3.0) >= 3.2.0

%description
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n %{libteam_name}
Summary:	Library for controlling 802.1AX team network device
Group:		System/Libraries

%description -n %{libteam_name}
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n %{libteamdctl_name}
Summary:	Library for controlling the team network device daemon
Group:		System/Libraries

%description -n %{libteamdctl_name}
Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n %{develname}
Summary:	Development files for libteam
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libteam_name} = %{version}
Requires:	%{libteamdctl_name} = %{version}

%description -n %{develname}
A library which is the user-space counterpart for the team network
driver, and provides an API to control them.

This package contains the development headers for the libteam and
libteamdctl libraries.

%package tools
Summary:	Utilities for controlling team network devices
Group:		System/Networking
Provides:	teamd = %{version}-%{release}

%description tools
This package contains frontends to libteam that allow changing
the (team-specific) properties of team devices.
(The general configuration of network devices can be done
through using iproute.)

Linux kernel 3.3 and above offer a so-called "team" network driver -
a lightweight mechanism for bonding multiple interfaces together.
It is a userspace-driven alternative to the existing bonding driver.

%package -n python3-team
Summary:	Python 3 bindings for libteam
Group:		Development/Python
%{?python_provide:%python_provide python3-team}
%{?python_provide:%python_provide python3-libteam}
Obsoletes:	python3-libteam < 1.29-2

%description -n python3-team
This package should be installed if you want to develop Python3
programs that will manipulate team network devices.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fi
%configure \
	--bindir=%{_sbindir} \
	--disable-static
%make_build

make html

pushd binding/python/
%pyproject_wheel
popd

%install
%make_install

pushd binding/python/
%pyproject_install
%pyproject_save_files team
popd

#teamd.conf file (mga#31700)
mkdir -p %{buildroot}%{_sysconfdir}/dbus-1/system.d
install -p teamd/dbus/teamd.conf %{buildroot}%{_sysconfdir}/dbus-1/system.d/

#systemd units
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 teamd/redhat/systemd/*.service %{buildroot}%{_unitdir}/

#we don't want these
find %{buildroot} -name "*.la" -delete

%check
make check

%files -n %{libteam_name}
%doc README
%license COPYING
%{_libdir}/libteam.so.%{libteam_major}{,.*}

%files -n %{libteamdctl_name}
%doc README
%license COPYING
%{_libdir}/libteamdctl.so.%{libteamdctl_major}{,.*}

%files -n %{develname}
%doc examples/*.c
%doc doc/api
%{_includedir}/team.h
%{_includedir}/teamdctl.h
%{_libdir}/libteam.so
%{_libdir}/libteamdctl.so
%{_libdir}/pkgconfig/libteam.pc
%{_libdir}/pkgconfig/libteamdctl.pc

%files tools
%doc teamd/example_configs teamd/redhat/example_ifcfgs/
%license COPYING
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/dbus-1/system.d/teamd.conf
%{_sbindir}/bond2team
%{_sbindir}/teamd
%{_sbindir}/teamdctl
%{_sbindir}/teamnl
%{_mandir}/man1/bond2team.1*
%{_mandir}/man5/teamd.conf.5*
%{_mandir}/man8/teamd.8*
%{_mandir}/man8/teamdctl.8*
%{_mandir}/man8/teamnl.8*
%{_unitdir}/teamd@.service

%files -n python3-team -f %{pyproject_files}


%changelog
* Tue Dec 24 2024 wally <wally> 1.32-3.mga10
+ Revision: 2129686
- add patches from upstream
- fix build with SWIG 4.3
- use pyproject rpm macros to build python pkg

* Sun Feb 11 2024 daviddavid <daviddavid> 1.32-2.mga10
+ Revision: 2040330
- rebuild for py3.12

* Wed Sep 20 2023 daviddavid <daviddavid> 1.32-1.mga10
+ Revision: 1988288
- new version 1.32

* Mon May 08 2023 papoteur <papoteur> 1.31-6.mga9
+ Revision: 1956175
- fix build with new swig 4.1.1

* Tue Mar 21 2023 daviddavid <daviddavid> 1.31-5.mga9
+ Revision: 1949912
- install missing teamd.conf file in "/etc/dbus-1/system.d/" (mga#31700)
- add also some docs in sub-pkgs and build html doc

* Sat Apr 02 2022 umeabot <umeabot> 1.31-4.mga9
+ Revision: 1840142
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 1.31-3.mga9
+ Revision: 1787103
- rebuild for python-3.10

* Sat Mar 27 2021 daviddavid <daviddavid> 1.31-2.mga9
+ Revision: 1711000
- rebuild for python 3.9

* Thu Nov 19 2020 daviddavid <daviddavid> 1.31-1.mga8
+ Revision: 1647719
- new version: 1.31

* Wed Feb 19 2020 daviddavid <daviddavid> 1.30-1.mga8
+ Revision: 1543868
- new version: 1.30

* Sun Feb 16 2020 umeabot <umeabot> 1.29-3.mga8
+ Revision: 1531367
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Sep 11 2019 wally <wally> 1.29-2.mga8
+ Revision: 1439692
- rebuild for python3.8
- rename python3 pkg as python3-team
- drop python2 support

* Fri Jul 12 2019 daviddavid <daviddavid> 1.29-1.mga8
+ Revision: 1420531
- new version: 1.29

* Tue Mar 26 2019 daviddavid <daviddavid> 1.28-1.mga7
+ Revision: 1380287
- new version: 1.28
- rename python-libteam to python2-libteam
- add Python3 support

* Sun Sep 23 2018 umeabot <umeabot> 1.26-2.mga7
+ Revision: 1299180
- Mageia 7 Mass Rebuild

* Sun Feb 19 2017 wally <wally> 1.26-1.mga6
+ Revision: 1086941
- new version 1.26

* Tue May 10 2016 tv <tv> 1.24-1.mga6
+ Revision: 1012098
- new release

* Thu Apr 07 2016 daviddavid <daviddavid> 1.23-4.mga6
+ Revision: 999049
- really add proper obsoletes after the name change

* Wed Apr 06 2016 tv <tv> 1.23-3.mga6
+ Revision: 998964
- add proper obsoletes after the name change

* Fri Feb 12 2016 daviddavid <daviddavid> 1.23-2.mga6
+ Revision: 959097
- use new python macros

* Thu Feb 11 2016 luigiwalser <luigiwalser> 1.23-1.mga6
+ Revision: 955866
- 1.23 (fixes build issues)
- fix nonsense library subpackage names
- do not use strange includedir
- remove nonsense service macro usage on template services
- make files list more specific
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Feb 19 2015 ovitters <ovitters> 1.15-1.mga5
+ Revision: 815849
- import package originally based on opensuse spec

